mchammer.Atom
=============

.. currentmodule:: mchammer

.. autoclass:: Atom
   :members:
   :inherited-members:
   :undoc-members:
   :show-inheritance:


   
   
   .. rubric:: Methods

   .. autosummary::
      :nosignatures:
   
      ~Atom.get_element_string
      ~Atom.get_id
      ~Atom.get_radius
   
   

   
   
   .. rubric:: Attributes

   .. autosummary::
   
      ~Atom.charge
      ~Atom.epsilon
      ~Atom.radius
      ~Atom.sigma
      ~Atom.id
      ~Atom.element_string
   
   